.. tsam documentation master file, created by
   sphinx-quickstart on Sat Nov 10 21:04:19 2018.


.. image:: https://www.fz-juelich.de/static/media/Logo.2ceb35fc.svg
    :target: https://www.fz-juelich.de/en/iek/iek-3
    :width: 230px
    :alt: Forschungszentrum Juelich Logo
    :align: right

Introduction
================================

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
tsam - time series aggregation module
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

tsam is a python package which uses different machine learning algorithms for the aggregation of typical periods. It is applicable
for all type of time series, either weather data, price data, behavioral data, electrical load data or all together. The module is able to significantly reduce input
time series for mathmatical models, and therefore the model's complexity and computational time.

To use tsam, first :ref:`install tsam<installation>` and then :ref:`start aggregating time series <start>`.

tsam is open-source available on `GitHub <https://github.com/FZJ-IEK3-VSA/tsam>`_
and open for collaboration, help requests etc.
In case you use tsam in a scientific publication, we kindly request you to cite one of our publications listed in the
:ref:`Further Reading Section <further_reading>`.

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    self
    installationDoc
    gettingStartedDoc
    structureOfTsamDoc
    mathematicalBackgroundDoc
    newsDoc
    integratedSoftwareDoc
    legalNoticeDoc
    furtherReadingDoc



